==> gradio-4.24.0.tar.gz: gradio-4.24.0/gradio/_frontend_code/icons/src/index.ts <==
export { default as Backward } from "./Backward.svelte";
export { default as Brush } from "./Brush.svelte";
export { default as BrushSize } from "./BrushSize.svelte";
export { default as Camera } from "./Camera.svelte";
export { default as Chart } from "./Chart.svelte";
export { default as Chat } from "./Chat.svelte";
export { default as Check } from "./Check.svelte";
export { default as Circle } from "./Circle.svelte";
export { default as Clear } from "./Clear.svelte";
export { default as Code } from "./Code.svelte";
export { default as Color } from "./Color.svelte";
export { default as Community } from "./Community.svelte";
export { default as Copy } from "./Copy.svelte";
export { default as Crop } from "./Crop.svelte";
export { default as Dislike } from "./Dislike.svelte";
export { default as Download } from "./Download.svelte";
export { default as DropdownArrow } from "./DropdownArrow.svelte";
export { default as Edit } from "./Edit.svelte";
export { default as Erase } from "./Erase.svelte";
export { default as Error } from "./Error.svelte";
export { default as Eyedropper } from "./Eyedropper.svelte";
export { default as Forward } from "./Forward.svelte";
export { default as File } from "./File.svelte";
export { default as Info } from "./Info.svelte";
export { default as Image } from "./Image.svelte";
export { default as ImagePaste } from "./ImagePaste.svelte";
export { default as JSON } from "./JSON.svelte";
export { default as Like } from "./Like.svelte";
export { default as LineChart } from "./LineChart.svelte";
export { default as Maximise } from "./Maximise.svelte";
export { default as Microphone } from "./Microphone.svelte";
export { default as Music } from "./Music.svelte";
export { default as Palette } from "./Palette.svelte";
export { default as Pause } from "./Pause.svelte";
export { default as Play } from "./Play.svelte";
export { default as Plot } from "./Plot.svelte";
export { default as Redo } from "./Redo.svelte";
export { default as Remove } from "./Remove.svelte";
export { default as Rotate } from "./Rotate.svelte";
export { default as Send } from "./Send.svelte";
export { default as Settings } from "./Settings.svelte";
export { default as Sketch } from "./Sketch.svelte";
export { default as Square } from "./Square.svelte";
export { default as Table } from "./Table.svelte";
export { default as TextHighlight } from "./TextHighlight.svelte";
export { default as Trash } from "./Trash.svelte";
export { default as Tree } from "./Tree.svelte";
export { default as Trim } from "./Trim.svelte";
export { default as Undo } from "./Undo.svelte";
export { default as Upload } from "./Upload.svelte";
export { default as Video } from "./Video.svelte";
export { default as VolumeLow } from "./VolumeLow.svelte";
export { default as VolumeHigh } from "./VolumeHigh.svelte";
export { default as VolumeMuted } from "./VolumeMuted.svelte";
export { default as Warning } from "./Warning.svelte";
export { default as Webcam } from "./Webcam.svelte";

==> gradio-4.40.0.tar.gz: gradio-4.40.0/gradio/_frontend_code/icons/src/index.ts <==
export { default as Back } from "./Back.svelte";
export { default as Backward } from "./Backward.svelte";
export { default as Brush } from "./Brush.svelte";
export { default as BrushSize } from "./BrushSize.svelte";
export { default as Calendar } from "./Calendar.svelte";
export { default as Camera } from "./Camera.svelte";
export { default as Chart } from "./Chart.svelte";
export { default as Chat } from "./Chat.svelte";
export { default as Check } from "./Check.svelte";
export { default as Circle } from "./Circle.svelte";
export { default as Clear } from "./Clear.svelte";
export { default as Code } from "./Code.svelte";
export { default as Color } from "./Color.svelte";
export { default as Community } from "./Community.svelte";
export { default as Copy } from "./Copy.svelte";
export { default as Crop } from "./Crop.svelte";
export { default as Download } from "./Download.svelte";
export { default as DropdownArrow } from "./DropdownArrow.svelte";
export { default as Edit } from "./Edit.svelte";
export { default as Erase } from "./Erase.svelte";
export { default as Error } from "./Error.svelte";
export { default as Eyedropper } from "./Eyedropper.svelte";
export { default as Forward } from "./Forward.svelte";
export { default as File } from "./File.svelte";
export { default as Info } from "./Info.svelte";
export { default as Image } from "./Image.svelte";
export { default as ImagePaste } from "./ImagePaste.svelte";
export { default as JSON } from "./JSON.svelte";
export { default as Layers } from "./Layers.svelte";
export { default as LineChart } from "./LineChart.svelte";
export { default as Maximise } from "./Maximise.svelte";
export { default as Microphone } from "./Microphone.svelte";
export { default as Music } from "./Music.svelte";
export { default as Palette } from "./Palette.svelte";
export { default as Paperclip } from "./Paperclip.svelte";
export { default as Pause } from "./Pause.svelte";
export { default as Play } from "./Play.svelte";
export { default as Plot } from "./Plot.svelte";
export { default as Redo } from "./Redo.svelte";
export { default as Remove } from "./Remove.svelte";
export { default as Rotate } from "./Rotate.svelte";
export { default as Send } from "./Send.svelte";
export { default as Settings } from "./Settings.svelte";
export { default as Sketch } from "./Sketch.svelte";
export { default as Square } from "./Square.svelte";
export { default as Table } from "./Table.svelte";
export { default as TextHighlight } from "./TextHighlight.svelte";
export { default as Trash } from "./Trash.svelte";
export { default as Tree } from "./Tree.svelte";
export { default as Trim } from "./Trim.svelte";
export { default as Undo } from "./Undo.svelte";
export { default as Upload } from "./Upload.svelte";
export { default as Video } from "./Video.svelte";
export { default as VolumeLow } from "./VolumeLow.svelte";
export { default as VolumeHigh } from "./VolumeHigh.svelte";
export { default as VolumeMuted } from "./VolumeMuted.svelte";
export { default as Warning } from "./Warning.svelte";
export { default as Webcam } from "./Webcam.svelte";
